function [net] = create_network(param)
% [net] = create_network(param);
%
% Create the CMR network given a param structure.
% 
% REQUIRES:
%
%  param.subregions
%  param.B_enc
%  param.B_rec
%  param.n_dimensions
%  param.lrate_fc_enc
%  param.lrate_cf_enc
%  param.lrate_fc_rec
%  param.lrate_cf_rec
%  param.eye_fc
%  param.eye_cf
%


% subregion parameters
for i=1:param.subregions
  net.c_sub{i}.B = param.B_enc(i);
  net.c_sub{i}.B_enc = param.B_enc(i);
  net.c_sub{i}.B_rec = param.B_rec(i);

  cum_dim = [0 cumsum(param.n_dimensions)];
  net.f_sub{i}.idx = cum_dim(i)+1:cum_dim(i+1);
  net.c_sub{i}.idx = cum_dim(i)+1:cum_dim(i+1);
end

% create the network structures
total_dimensions = sum(param.n_dimensions);

% the layers
net.f = zeros(total_dimensions,1);
net.c = zeros(total_dimensions,1);

% the learning rate matrices
net.lrate_fc = zeros(total_dimensions);
net.lrate_cf = zeros(total_dimensions);

for i=1:length(net.f_sub)
  for j=1:length(net.c_sub)
    % the lrate matrices
    net.lrate_fc_enc(net.c_sub{j}.idx,net.f_sub{i}.idx) = ...
	param.lrate_fc_enc(i,j);
    net.lrate_cf_enc(net.f_sub{j}.idx,net.c_sub{i}.idx) = ...
	param.lrate_cf_enc(i,j);
    net.lrate_fc_rec(net.c_sub{j}.idx,net.f_sub{i}.idx) = ...
	param.lrate_fc_rec(i,j);
    net.lrate_cf_rec(net.f_sub{j}.idx,net.c_sub{i}.idx) = ...
	param.lrate_cf_rec(i,j);
  end
end

% create the connecting weight matrices
net.w_fc = eye(length(net.c),length(net.f)) * param.eye_fc;
net.w_cf = eye(length(net.f),length(net.c)) * param.eye_cf;


