function [net, env] = create_semantic_structure(net, env, param)
%
% Assumes that the patterns are orthonormal localist patterns, and
% that the items are the first patterns generated when patterns are
% created (prior to distraction patterns). 
%

for i = 1:param.subregions
  if param.has_semantic_structure(i)
    % grab the indices of the to-be-presented items
    these_pool_inds = env.pool_to_item_map{i}(:,1);
    these_pat_inds = env.pool_to_item_map{i}(:,2);
    sem_mat = param.sem_mat{i}(these_pool_inds, these_pool_inds);      
    % check to see if there are any NaNs (words missing from the pool)
    if any(isnan(sem_mat(:)))
      error('semantic matrix contains missing values');
    end
    
    % scale these by the s parameter
    sem_mat = sem_mat * param.s;
    
    % the self connections are removed
    n = length(sem_mat);
    diag_ind = [1:n]+[0:n-1]*n;
    sem_mat(diag_ind) = 0;
    
    % place these sem strengths in the w_cf matrix
    
    irange = net.f_sub{i}.idx(1:length(these_pat_inds));
    net.w_cf(irange,irange) = net.w_cf(irange,irange) + sem_mat;
    
  end
end

net.sem_mat = sem_mat;
