function param = param_cmr_m62
% param = param_cmr_m62
%
% This function creates a parameters structure for use with the CMR
% model.  Update param.sem_path to reflect the local path to the
% semantic similarity file.
%
% These parameters were found using a genetic algorithm fitting
% procedure and are reported in Table 1 of the Polyn et
% al. manuscript, parameter set M62.
%
% Note that a conversion is needed between the values for eta
% and tau reported here and those appearing in the manuscript.
% See README.txt, FAQ Q1.
%
% % Example:
% param = param_cmr_m62;
%

param.LL = [20 30 40];
param.num_trials = 200;

param.subregions = 1;
param.not_presented_indices{1} = [];

param.custom_context_fn{1} = @context_update;
param.recall_task_fn = @fr_task;
param.post_recall_decision = 0;
param.reset = true;
param.can_repeat = 0;
param.alpha = 0;
param.omega = 0;

param.B_enc = 0.745;
param.B_rec = 0.36;
param.p_scale = 5.39;
param.p_decay = 1.41;
param.gamma_fc = 0.581;
param.lrate_fc_enc = param.gamma_fc;
param.lrate_cf_enc = 1;
param.lrate_fc_rec = 0;
param.lrate_cf_rec = 0;
param.eye_fc = 1 - param.gamma_fc;
param.eye_cf = 0;
param.s = 1.80;
param.K = 0.091;
param.L = 0.375;
param.eta = 0.3699;
param.tau = 413;
param.dt = 100;
param.thresh = 1;
param.support_thresh = 0.0001;

param.rec_time = 90000;
param.recall_regions = 1;

param.init_orthogonal_index = 1;
param.has_semantic_structure = 1;
param.sem_path{1} = '~/matlab/CMR_repository/resources/LSA_tfr.mat';
param.orthogonal_patterns = 1;

param.do_cdfr = 0;
param.do_dfr = 0;
param.do_shift = 0;
param.do_end_list = 0;




