function net = present_item(net, env, param)
%   PRESENT_ITEM
%
%   The presentation of an item during a study period.
%
%
%   INPUTS:
%
%       net:  net.f
%                .f_sub
%                .w_fc
%                .w_cf
%                .c
%                .c_sub
%                .lrate_fc
%                .lrate_cf
%
%       env:
% 
%     param:
%


% a flag which triggers normalization of the input to the context
% layer
if ~isfield(param,'c_in_norm')
  for i=1:param.subregions
    param.c_in_norm(i) = 1;
  end
end


% ACTIVATE FEATURES % 
net.f = zeros(size(net.f));

for i=1:length(net.f_sub)
  if env.present_index(i) > 0
    net.f(net.f_sub{i}.idx) = env.patterns{i}(env.present_index(i),:);
  end
end

% UPDATE CONTEXT REPRESENTATION %
net.c_in = net.w_fc * net.f;
for i=1:length(net.c_sub)
  subregion = i;
  net = param.custom_context_fn{i}(net, subregion, param);
end

% ASSOCIATION FORMATION %

% calculate primacy gradient
prime_fact = (param.p_scale * ...
	      exp(-param.p_decay * (env.list_position - 1))) + 1;

% determine current learning rate
lrate_fc = net.lrate_fc_enc;
lrate_cf = (net.lrate_cf_enc .* prime_fact);

% weight update
% w_fc
delta = (net.c * net.f') .* lrate_fc;
net.w_fc = net.w_fc + delta;
% w_cf
delta = (net.f * net.c') .* lrate_cf;
net.w_cf = net.w_cf + delta;